@@ -7,7 +7,7 @@ RDF::Query::Node::Resource - RDF Node class for resources
 
 =head1 VERSION
 
-This document describes RDF::Query::Node::Resource version 2.916.
+This document describes RDF::Query::Node::Resource version 2.917.
 
 =cut
 
@@ -29,7 +29,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.916';
+	$VERSION	= '2.917';
 }
 
 ######################################################################
@@ -74,6 +74,7 @@ Returns the SPARQL string for this node.
 
 sub as_sparql {
 	my $self	= shift;
+	my $PNLOCAL	= $RDF::Query::Parser::SPARQL::r_PN_LOCAL;
 	my $context	= shift || {};
 	if ($context) {
 		my $uri		= $self->uri_value;
@@ -87,7 +88,8 @@ sub as_sparql {
 			my $v	= $ns{ $k };
 			if (index($uri, $v) == 0) {
 				my $local	= substr($uri, length($v));
-				if ($local =~ $RDF::Query::Parser::SPARQL::r_PN_LOCAL) {
+				
+				if ($local =~ /^(?:$PNLOCAL)$/) {
 					my $qname	= join(':', $k, $local);
 					return $qname;
 				}
